@@ -12,7 +12,7 @@ use Plack::Util;
 use Plack::Util::Accessor qw/ filter callback /;
 use HTTP::Status ();
 
-our $VERSION = 'v0.3.1';
+our $VERSION = 'v0.3.2';
 
 
 sub prepare_app {
@@ -71,7 +71,7 @@ Plack::Middleware::EmulateOPTIONS - handle OPTIONS requests as HEAD
 
 =head1 VERSION
 
-version v0.3.1
+version v0.3.2
 
 =head1 SYNOPSIS
 
@@ -145,12 +145,6 @@ If you need this module on Perl v5.10, please use one of the v0.2.x
 versions of this module.  Significant bug or security fixes may be
 backported to those versions.
 
-=head1 SEE ALSO
-
-L<Plack>
-
-L<PSGI>
-
 =head1 SOURCE
 
 The development version is on github at L<https://github.com/robrwo/Plack-Middleware-EmulateOPTIONS>
